@@ -1,11 +1,36 @@
-from pathlib import Path
-import pandas as pd
-from sequana import logger
+# -*- coding: utf-8 -*-
+#
+#  This file is part of Sequana software
+#
+#  Copyright (c) 2016,2020 - Sequana Development Team
+#
+#  File author(s):
+#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
+#      Etienne Kornobis <etienne.kornobis@pasteur.fr>
+#
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  website: https://github.com/sequana/sequana
+#  documentation: http://sequana.readthedocs.io
+#
+##############################################################################
 import re
+from pathlib import Path
+
+import pandas as pd
+
+from sequana.lazy import pylab
+from sequana import logger
 
 logger.name = __name__
 
 
+__all__ = ['get_most_probable_strand_consensus', 'get_most_probable_strand',
+    'MultiFeatureCount', 'FeatureCount']
+
+
+
 def get_most_probable_strand(sample_folder, tolerance):
     """Return total counts by strand from featureCount matrix folder, strandness and
     probable strand for a single sample (using a tolerance threshold for
@@ -26,13 +51,13 @@ def get_most_probable_strand(sample_folder, tolerance):
     res_dict["strandness"] = strandness
 
     if strandness < tolerance:
-        res_dict["strand"] = "2"
+        res_dict["strand"] = 2
     elif strandness > 1 - tolerance:
-        res_dict["strand"] = "1"
+        res_dict["strand"] = 1
     elif 0.5 - tolerance < strandness and strandness < 0.5 + tolerance:
-        res_dict["strand"] = "0"
+        res_dict["strand"] = 0
     else:
-        res_dict["strand"] = "NA"
+        res_dict["strand"] = None
 
     df = pd.DataFrame(res_dict, index=[sample_name])
 
@@ -43,6 +68,8 @@ def get_most_probable_strand_consensus(rnaseq_folder, tolerance):
     """From a sequana rna-seq run folder get the most probable strand, based on the
     frequecies of counts assigned with '0', '1' or '2' type strandness
     (featureCounts nomenclature)
+
+    If guess is not possible given the tolerance, fills with None
     """
 
     rnaseq_folder = Path(rnaseq_folder)
@@ -56,19 +83,50 @@ def get_most_probable_strand_consensus(rnaseq_folder, tolerance):
             for sample_folder in sample_folders
         ]
     )
+    df = df[['0','1','2', 'strandness', 'strand']]
 
-    logger.info("Strand guessing for each files (tolerance: {tolerance}):\n {df}")
+    logger.info(f"Strand guessing for each files (tolerance: {tolerance}):\n")
     logger.info(df)
 
-    probable_strands = df.loc[:, "strand"].unique()
+    try:
+        most_probable = df['strand'].value_counts().idxmax()
+    except:
+        # if all events are None, return -1
+        most_probable = -1
+
+    return most_probable, df
+
+
+
+class MultiFeatureCount():
+    # USED in rnaseq pipeline
+
+    def __init__(self, rnaseq_folder='.', tolerance=0.1):
+        self.tolerance = tolerance
+        self.rnaseq_folder = rnaseq_folder
+
+    def get_most_probable_strand_consensus(self):
+        most_probable, df = get_most_probable_strand_consensus(
+            self.rnaseq_folder,
+            self.tolerance)
+        return most_probable, df
+
+    def plot_strandness(self, fontsize=12, output_filename='strand_summary.png',
+        savefig=False):
+        # USED in rnaseq pipeline
+        most_probable, df = self.get_most_probable_strand_consensus()
+
+        df = df.sort_index(ascending=False)
+        df['strandness'] = df['strandness'].T
+        df['strandness'].plot( kind='barh')
+        pylab.xlim([0, 1])
+        pylab.grid(True)
+        pylab.axvline(self.tolerance, ls='--', color='r')
+        pylab.xlabel("Strandness", fontsize=fontsize)
+        pylab.tight_layout()
+        if savefig:
+            pylab.savefig(output_filename)
 
-    if len(probable_strands) == 1:
-        return probable_strands[0]
-    else:
-        raise IOError(
-            f"No consensus on most probable strand found with a tolerance of {tolerance}. \
-Could be: {' or '.join(str(x) for x in probable_strands)}."
-        )
 
 
 class FeatureCount:
@@ -161,24 +219,3 @@ class FeatureCount:
         return new_name
 
 
-class MultiFeatureCount:
-    """ IN DEV. Read multiple features. NOT FUNCTIONAL YET
-    """
-
-    def __init__(
-        self,
-        filenames,
-        clean_sample_names=True,
-        extra_name_rm=["_Aligned"],
-        drop_loc=True,
-    ):
-        self.filenames = filenames
-        self.clean_sample_names = clean_sample_names
-        self.extra_name_rm = extra_name_rm
-        self.drop_loc = drop_loc
-        self._data = []
-
-        self._df = self._get_df()
-
-    def _get_df(self):
-        pass
